# Resources: IATI Standard

The folder (and sub-folders) contain data that is used by the library that relates to the IATI Standard.

Data for a given version of the Standard is stored within a corresponding folder – for example version 2.02 data is contained with the `202` folder.  Note that this contains all content for that version of the standard, symlinks are used to ensure content replicated across multiple versions of the Standard - for example non-embedded codelists – is not replicated for each version of the Standard.

Currently non-embedded codelists are stored within the `codelists_non_embedded` folder. Due to the relevant modification schedule, it may be desired to nest them within a `2xx` folder.
